@@ -1,12 +1,13 @@
 import logging
 
+from django.core.exceptions import PermissionDenied
 from django.db import transaction
 from django.http import HttpRequest
 from django.http.response import HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404, render
 from django.views import View
 
-from magic_link.models import InvalidTokenUse, MagicLink
+from magic_link.models import InvalidLink, MagicLink
 
 logger = logging.getLogger(__name__)
 
@@ -22,20 +23,21 @@ class MagicLinkView(View):
         """
         link = get_object_or_404(MagicLink, token=token)
         try:
-            link.validate(request)
-        except InvalidTokenUse as ex:
-            link.log_use(request, ex)
+            link.validate()
+            link.authorize(request.user)
+        except (PermissionDenied, InvalidLink) as ex:
+            link.audit(request, error=ex)
             return render(
                 request,
-                template_name="error.html",
+                template_name="magic_link/error.html",
                 context={"link": link, "error": ex},
                 status=403,
             )
         else:
-            link.log_use(request)
+            link.audit(request)
             return render(
                 request,
-                template_name="logmein.html",
+                template_name="magic_link/logmein.html",
                 context={"link": link},
                 status=200,
             )
@@ -56,17 +58,18 @@ class MagicLinkView(View):
         """
         link = get_object_or_404(MagicLink, token=token)
         try:
-            link.validate(request)
-        except InvalidTokenUse as ex:
-            link.log_use(request, ex)
+            link.validate()
+            link.authorize(request.user)
+        except (PermissionDenied, InvalidLink) as ex:
+            link.audit(request, error=ex)
             return render(
                 request,
-                template_name="error.html",
+                template_name="magic_link/error.html",
                 context={"link": link, "error": ex},
                 status=403,
             )
         else:
-            link.log_use(request)
             link.login(request)
             link.disable()
+            link.audit(request, timestamp=link.logged_in_at)
             return HttpResponseRedirect(link.redirect_to)
